==> proxy-server-react-0.3.4.tgz: package/src/utils/index.ts <==
import Router from 'koa-router';
import axios from 'axios';
import fs from 'fs';
import { resolve } from '../config';

const METHOD_MAP = {
  GET: 'get',
  POST: 'post',
  PUT: 'put',
  PATCH: 'patch',
  DELETE: 'del',
} as const;

const getBackEndUrl = (ctx: any) => {
  const { url, appConfig, request } = ctx;

  console.log('proxy router url is => ', url);
  console.log('proxy router query is => ', request.query);
  console.log('proxy router config is => ', appConfig);

  return '/';
};

export const isSimpleObject = (target: any) =>
  Object.prototype.toString.call(target) === '[object Object]';

export const setRouter = (router: Router) => {
  const customRouterPath = resolve('routes');

  if (fs.existsSync(customRouterPath)) {
    try {
      fs.readdirSync(customRouterPath).forEach(item => {
        if (/\.js$/g.test(item)) {
          const controolerExport = require(`${customRouterPath}/${item}`);
          const controoler = controolerExport.default
            ? controolerExport.default
            : controolerExport;
          typeof controoler === 'function' && controoler(router);
        }
      });
    } catch (error) {}
  }

  router.all('/common/proxy/:serviceCode', async (ctx, next) => {
    const { request, header } = ctx;
    const { query, body, method } = request as any;

    const path = getBackEndUrl(ctx);

    const result = await axios({
      url: path,
      method: METHOD_MAP[method as keyof typeof METHOD_MAP],
      params: query,
      data: body,
      headers: header as any,
    });

    ctx.body = result;

    await next();
  });
};

==> proxy-server-react-0.3.5.tgz: package/src/utils/index.ts <==
import Router from 'koa-router';
import axios from 'axios';
import fs from 'fs';
import { resolve } from '../config';

const METHOD_MAP = {
  GET: 'get',
  POST: 'post',
  PUT: 'put',
  PATCH: 'patch',
  DELETE: 'del',
} as const;

const getBackEndUrl = (ctx: any) => {
  const { url, appConfig } = ctx;
  const urlMatch = url.match(/^\/common\/proxy\/([a-z]+)(.*)/);
  const serviceCode = urlMatch?.[1];
  const path = urlMatch?.[2];
  const host = appConfig.proxyConfig?.[serviceCode]?.url;
  if (!host) throw new Error('proxy error host is required');
  if (!path) throw new Error('proxy error path is required');
  return `${host}/${path}`;
};

export const isSimpleObject = (target: any) =>
  Object.prototype.toString.call(target) === '[object Object]';

export const setRouter = (router: Router) => {
  const customRouterPath = resolve('routes');

  if (fs.existsSync(customRouterPath)) {
    try {
      fs.readdirSync(customRouterPath).forEach(item => {
        if (/\.js$/g.test(item)) {
          const controolerExport = require(`${customRouterPath}/${item}`);
          const controoler = controolerExport.default
            ? controolerExport.default
            : controolerExport;
          typeof controoler === 'function' && controoler(router);
        }
      });
    } catch (error) {}
  }

  router.all(/^common\/proxy\/*/, async (ctx, next) => {
    const { request, header } = ctx;
    const { query, body, method } = request as any;

    const path = getBackEndUrl(ctx);

    const result = await axios({
      url: path,
      method: METHOD_MAP[method as keyof typeof METHOD_MAP],
      params: query,
      data: body,
      headers: header as any,
    });

    ctx.body = result;

    await next();
  });
};
